SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN = (function ( self ) {
    var _timeout = 0;
    var _current_window;
    var _current_property;
    var _to_test;
    
    function ____ ( fct ) {
        _timeout += fct;
        return _timeout;
    }
    
    self.do = function () {
        switch ( __shinken_test_type ) {
            case"00195":
                switch ( __phase ) {
                    case 1:
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.visibility( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.DOM.getMenu(), "barre du menu", true ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.openUserConfiguration( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.logout( _timeout ) );
                        break;
                    case 2:
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.DOM.getMenu() ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LOGIN.ACTION.setInputValue( _timeout, "username", "test_auto_user_executor" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LOGIN.ACTION.setInputValue( _timeout, "password", "test_auto_user_executor" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LOGIN.ACTION.login( _timeout ) );
                        __do_next = false;
                        break;
                    case 3:
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.visibility( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.DOM.getMenu(), "barre du menu", true ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.userNameLabel( _timeout, 'test_auto_user_executor' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasStyle( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.DOM.getMenu(), "height", 63, "barre du menu" ) );
                        break;
                    case 4:
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnMenu( _timeout, SHINKEN.SCREEN.TYPE.HIVE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.HIVE, "menu_expand_default_hive" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.HIVE, "menu_expand_new_hive" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnMenu( _timeout, SHINKEN.SCREEN.TYPE.LIST ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.LIST, "menu_expand_list_all" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.LIST, "menu_expand_list_root" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.LIST, "menu_expand_new_list" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnMenu( _timeout, SHINKEN.SCREEN.TYPE.EVENT ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.EVENT, "menu_expand_list_event" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_new_service_weather" ) );
                        break;
                    case 5:
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnMenu( _timeout, SHINKEN.SCREEN.TYPE.LIST ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.LIST, "menu_expand_list_all" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnMenu( _timeout, SHINKEN.SCREEN.TYPE.HIVE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.HIVE, "menu_expand_default_hive" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.HIVE ) );
                        break;
                    case 6:
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.LIST, "menu_expand_list_all" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.TEST.statePanelsModal( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS_CONST.STATE.HIDDEN ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.LIST ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.TEST.statePanelsModal( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS_CONST.STATE.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.LIST ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.askForRemoveByIndex( _timeout, 1 ) ); //INDEX 1 ?? 0 ?? DOESNT WORK
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.HIVE, "menu_expand_default_hive" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.LIST ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.validClosePopup( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.TEST.statePanelsModal( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS_CONST.STATE.HIDDEN ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.HIVE ) );
                        break;
                    case 7:
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.LIST, "menu_expand_list_all" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.askForRemoveByIndex( _timeout, 1 ) ); //INDEX 1 ?? 0 ?? DOESNT WORK
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.HIVE, "menu_expand_default_hive" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.LIST ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.cancelClosePopup( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.TEST.statePanelsModal( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS_CONST.STATE.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.LIST ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.closePanelsModal( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.validClosePopup( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.TEST.statePanelsModal( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS_CONST.STATE.HIDDEN ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.LIST ) );
                        break;
                    case 8:
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.TEST.statePanelsModal( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS_CONST.STATE.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.askForRemoveByIndex( _timeout, 1 ) );//INDEX 1 ?? 0 ?? DOESNT WORK
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.closePanelsModal( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.TEST.statePanelsModal( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS_CONST.STATE.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.cancelClosePopup( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.cancelAllUserActionAsk( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.validClosePopup( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.TEST.statePanelsModal( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS_CONST.STATE.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.closePanelsModal( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.TEST.statePanelsModal( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS_CONST.STATE.HIDDEN ) );
                        break;
                }
                break;
            case "00196": //NAVIGATION
                switch ( __phase ) {
                    case 1:
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnMenu( _timeout, "shinken-extra-menu-cell" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, "shinken-extra-menu-cell", "menu_expand_reporting" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.REPORTING ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_REPORT.ACTION.setInputValue( _timeout, "filter", "00001_test_auto" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_REPORT.ACTION.setInputValue( _timeout, "dateBegin", DATE_TIME.FORMAT.get_date( DATE_TIME.now() ) ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_REPORT.ACTION.setInputValue( _timeout, "dateEnd", DATE_TIME.FORMAT.get_date( DATE_TIME.now() ) ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_REPORT.ACTION.clickOnSubmitForm( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.REPORTING_WEB ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_REPORT.ACTION.clickOnModifySelection( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.REPORTING ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_REPORT.TEST.inputValue( _timeout, "filter", "00001_test_auto" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_REPORT.ACTION.clickOnSubmitForm( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.REPORTING_WEB ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_REPORT.ACTION.clickOnNewSelection( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.REPORTING ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_REPORT.TEST.inputValue( _timeout, "filter", "" ) );
                        break;
                    case 2:
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnMenu( _timeout, "shinken-extra-menu-cell" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, "shinken-extra-menu-cell", "menu_expand_impacts" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.IMPACTS ) );
                        break;
                    case 3:
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnMenu( _timeout, "shinken-extra-menu-cell" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, "shinken-extra-menu-cell", "menu_expand_360" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.VIEW360 ) );
                        break;
                    case 4: //COLLAPSED MENU
                        ____( SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW.ACTION.openFull( _timeout, SHINKEN.HIGHWAY.getPathOrigin() ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.displayState( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.CONST.STATE_DISPLAY.VISIBLE, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO.ACTION.do_JS_action( _timeout, "SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW.instance.resizeTo(1000," + window.innerHeight + ")", 500 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.displayState( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.CONST.STATE_DISPLAY.VISIBLE_AND_COLLAPSE, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnMenu( _timeout, "shinken-collapsed-menu-cell", SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, "shinken-collapsed-menu-cell", "menu_collapse_list_all", SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.LIST, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, "shinken-collapsed-menu-cell", "menu_collapse_list_event", SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.EVENT, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, "shinken-collapsed-menu-cell", "menu_collapse_new_service_weather", SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, "shinken-collapsed-menu-cell", "menu_collapse_360", SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.VIEW360, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, "shinken-collapsed-menu-cell", "menu_collapse_impacts", SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.IMPACTS, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, "shinken-collapsed-menu-cell", "menu_collapse_reporting", SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.REPORTING, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, "shinken-collapsed-menu-cell", "menu_collapse_default_hive", SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.activeView( _timeout, SHINKEN.SCREEN.TYPE.HIVE, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW.ACTION.close( _timeout ) );
                        break;
                }
                break;
            case "00197": //LICENCE
                switch ( __phase ) {
                    case 1:
                        ____( SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor", "test_auto_user_executor" ) );
                        break;
                    case 2:
                        ____( SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW.ACTION.openFull( _timeout, SHINKEN.HIGHWAY.getPathOrigin() ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.HIDDEN, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.HIDDEN, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NO_LICENCE, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NO_LICENCE, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.IS_DUPLICATED_TRIAL, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.IS_DUPLICATED_TRIAL, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.INVALID_FORMAT, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.INVALID_FORMAT, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.LICENSE_EXPIRED, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.LICENSE_EXPIRED, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NODE_LIMIT_EXCEEDED, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NODE_LIMIT_EXCEEDED, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.LESS_THAN_10_PERCENT_OF_THE_HOST_LIMIT, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.LESS_THAN_10_PERCENT_OF_THE_HOST_LIMIT, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.TESTING_VERSION, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.TESTING_VERSION, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS_AND_NODE_LIMIT_EXCEEDED, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS_AND_NODE_LIMIT_EXCEEDED, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS_AND_LESS_THAN_10_PERCENT_OF_THE_HOST_LIMIT, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS_AND_LESS_THAN_10_PERCENT_OF_THE_HOST_LIMIT, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW.ACTION.close( _timeout ) );
                        break;
                    case 3:
                        ____( SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor_si", "test_auto_user_executor_si" ) );
                        break;
                    case 4:
                        ____( SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW.ACTION.openFull( _timeout, SHINKEN.HIGHWAY.getPathOrigin() ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.HIDDEN, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.HIDDEN, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.HIDDEN, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.TESTING_VERSION, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.HIDDEN, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.LESS_THAN_10_PERCENT_OF_THE_HOST_LIMIT, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.HIDDEN, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS_AND_LESS_THAN_10_PERCENT_OF_THE_HOST_LIMIT, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.HIDDEN, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_7_DAYS, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_7_DAYS, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NO_LICENCE, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NO_LICENCE, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.IS_DUPLICATED_TRIAL, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.IS_DUPLICATED_TRIAL, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.INVALID_FORMAT, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.INVALID_FORMAT, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.LICENSE_EXPIRED, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.LICENSE_EXPIRED, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NODE_LIMIT_EXCEEDED, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NODE_LIMIT_EXCEEDED, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.ACTION.setConfiguration( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.REMAINING_60_DAYS_AND_NODE_LIMIT_EXCEEDED, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.TEST.display( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LICENCE.CONST.STATE.NODE_LIMIT_EXCEEDED, SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW.ACTION.close( _timeout ) );
                        break;
                    case 5:
                        ____( SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor", "test_auto_user_executor" ) );
                        break;
                    
                }
                break;
            case "00199":
                switch ( __phase ) {
                    case 1:
                        ____( SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor", "test_auto_user_executor" ) );
                        break;
                    case 2: //CLEAN ALL CONTENT EXCEPT WEATHER_DEFAULT_UUID
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_new_service_weather" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.resetPanelContent( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.applyAllUserActionAsk( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.validClosePopup( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.closePanelsModal( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.ACTION.createWeather( _timeout, "test_auto_1" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.ACTION.createWeather( _timeout, "test_auto_2" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.ACTION.createWeather( _timeout, "test_auto_3", "test_auto_user_executor_4" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.ACTION.createWeather( _timeout, "test_auto_4", "test_auto_user_executor_3" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.ACTION.createWeather( _timeout, "test_auto_5" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.ACTION.createWeather( _timeout, "test_auto_6", "test_auto_user_executor_1" ) );
                        _timeout += 5000;
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.viewsNumber( _timeout, 7, 7 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.filter( _timeout, "name", "test_auto_1" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.viewsNumber( _timeout, 7, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.filter( _timeout, "name", "test_auto" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.viewsNumber( _timeout, 7, 6 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.filter( _timeout, "current_owner", "test_auto_user_executor_4" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.viewsNumber( _timeout, 7, 1 ) );
                        break;
                    case 3: //TEST STRUCTURE AND INTERACTIONS
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.headersNumber( _timeout, 9 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.filtersNumber( _timeout, 9 ) );
                        break;
                    case 4: //TRI + SHIFT CLICK
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.clickOnHeaderLabel( _timeout, "name", true ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.sorting( _timeout, "name", 1, SHINKEN.OBJECT.Sorting.CONST.STATUS.INCREASING ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.clickOnHeaderLabel( _timeout, "name", true ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.sorting( _timeout, "name", 1, SHINKEN.OBJECT.Sorting.CONST.STATUS.DECREASING ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.clickOnHeaderLabel( _timeout, "name", true ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.sorting( _timeout, "name", 0, SHINKEN.OBJECT.Sorting.CONST.STATUS.NONE ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.clickOnHeaderLabel( _timeout, "name", true ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.clickOnHeaderLabel( _timeout, "current_owner", true ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.clickOnHeaderLabel( _timeout, "previous_owner", true ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.clickOnHeaderLabel( _timeout, "creator", true ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.clickOnHeaderLabel( _timeout, "creator", true ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.sorting( _timeout, "name", 1, SHINKEN.OBJECT.Sorting.CONST.STATUS.INCREASING ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.sorting( _timeout, "current_owner", 2, SHINKEN.OBJECT.Sorting.CONST.STATUS.INCREASING ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.sorting( _timeout, "previous_owner", 3, SHINKEN.OBJECT.Sorting.CONST.STATUS.INCREASING ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.sorting( _timeout, "creator", 4, SHINKEN.OBJECT.Sorting.CONST.STATUS.DECREASING ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.clickOnHeaderLabel( _timeout, "name", true ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.clickOnHeaderLabel( _timeout, "name", true ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.sorting( _timeout, "name", 0, SHINKEN.OBJECT.Sorting.CONST.STATUS.NONE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.sorting( _timeout, "current_owner", 1, SHINKEN.OBJECT.Sorting.CONST.STATUS.INCREASING ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.sorting( _timeout, "previous_owner", 2, SHINKEN.OBJECT.Sorting.CONST.STATUS.INCREASING ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.sorting( _timeout, "creator", 3, SHINKEN.OBJECT.Sorting.CONST.STATUS.DECREASING ) );
                        
                        break;
                    case 5: //CHANGE NAME + FILTER & SORTING
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_new_service_weather" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.resetPanelContent( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.applyAllUserActionAsk( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.validClosePopup( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.closePanelsModal( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.ACTION.createWeather( _timeout, "test_auto_1" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.ACTION.createWeather( _timeout, "test_auto_2", "zz_test_auto_to_change" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.ACTION.createWeather( _timeout, "test_auto_3", "yy_to_keep" ) );
                        _timeout += 5000;
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.clickOnChangeUser( _timeout, "test_auto_2" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.filterUserInChangeUser( _timeout, "test_auto_2", "test_auto_user_executor" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.validChangeUserInInput( _timeout, "test_auto_2" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.filter( _timeout, "current_owner", "test_auto_user_executor" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.viewsNumber( _timeout, 4, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.filter( _timeout, "current_owner", "" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.clickOnHeaderLabel( _timeout, "current_owner", true ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.displayAtLine( _timeout, "test_auto_3", 3 ) );
                        break;
                    case 6: //CLICK ON OPTION FOR SORT
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.resetPanelContent( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.applyAllUserActionAsk( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.validClosePopup( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.closePanelsModal( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.ACTION.createWeather( _timeout, "test_auto_1" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.ACTION.createWeather( _timeout, "test_auto_2", "zz_test_auto_to_change" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.ACTION.createWeather( _timeout, "test_auto_3", "yy_to_keep" ) );
                        _timeout += 5000;
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.clickOnHeaderMenu( _timeout, "name" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.clickOnHeaderMenuOption( _timeout, "name", SHINKEN.OBJECT.Sorting.CONST.STATUS.INCREASING ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.clickOnHeaderMenu( _timeout, "current_owner" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.clickOnHeaderMenuOption( _timeout, "current_owner", SHINKEN.OBJECT.Sorting.CONST.STATUS.DECREASING ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.clickOnHeaderMenu( _timeout, "previous_owner" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.clickOnHeaderMenuOption( _timeout, "previous_owner", SHINKEN.OBJECT.Sorting.CONST.STATUS.INCREASING ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.sorting( _timeout, "name", 1, SHINKEN.OBJECT.Sorting.CONST.STATUS.INCREASING ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.sorting( _timeout, "current_owner", 2, SHINKEN.OBJECT.Sorting.CONST.STATUS.DECREASING ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.sorting( _timeout, "previous_owner", 3, SHINKEN.OBJECT.Sorting.CONST.STATUS.INCREASING ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.clickOnHeaderMenu( _timeout, "name" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.clickOnHeaderMenuOption( _timeout, "name", SHINKEN.OBJECT.Sorting.CONST.STATUS.NONE ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.sorting( _timeout, "name", 0, SHINKEN.OBJECT.Sorting.CONST.STATUS.NONE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.sorting( _timeout, "current_owner", 1, SHINKEN.OBJECT.Sorting.CONST.STATUS.DECREASING ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.sorting( _timeout, "previous_owner", 2, SHINKEN.OBJECT.Sorting.CONST.STATUS.INCREASING ) );
                        
                        
                        
                        break;
                    case 7: //CHANGE NAME + FILTER & SORTING
                        //__do_next = false;
                        ____( SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor_si", "test_auto_user_executor_si" ) );
                        
                        
                        
                        break;
                    case 8: //CHANGE NAME + FILTER & SORTING
                        //__do_next = false;
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_light" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.headersNumber( _timeout, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.filtersNumber( _timeout, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.filter( _timeout, "current_owner", "test_auto_user_executor" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.viewsNumber( _timeout, 4, 2 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.filter( _timeout, "current_owner", "" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.clickOnHeaderLabel( _timeout, "current_owner" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.displayAtLine( _timeout, "test_auto_3", 2 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.clickOnHeaderLabel( _timeout, "current_owner" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.displayAtLine( _timeout, "test_auto_3", 1 ) );
                        
                        break;
                }
                break;
            case "00200":
                switch ( __phase ) {
                    case 1:
                        ____( SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor", "test_auto_user_executor" ) );
                        break;
                    case 2: //NUMBER ERROR WEATHER PREVIEW
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.resetPanelContent( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.applyAllUserActionAsk( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.validClosePopup( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.closePanelsModal( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.ACTION.createWeather( _timeout, "test_auto_1" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.ACTION.createWeather( _timeout, "test_auto_2", "zz_invalid_user" ) );
                        _timeout += 5000;
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.counter( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "1" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.resetPanelContent( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.applyAllUserActionAsk( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.validClosePopup( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.closePanelsModal( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.counter( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "" ) );
                        break;
                }
                break;
            case "00222":
                ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.HIVE, "menu_expand_default_hive" ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_ANGULAR.TEST.displayHelp( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_ANGULAR_CONST.STATE.HIDDEN ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_ANGULAR.ACTION.clickOnHelpButton( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_ANGULAR.TEST.displayHelp( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_ANGULAR_CONST.STATE.VISIBLE ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.LIST, "menu_expand_list_all" ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_ANGULAR.TEST.displayHelp( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_ANGULAR_CONST.STATE.HIDDEN ) );
                break;
            case "00233":
                var user_properties_configuration_path    = "/etc/shinken-user/configuration/elements_default_properties/default_properties_configuration.cfg";
                var default_properties_configuration_path = "/etc/shinken/_default/elements_default_properties/default_properties_configuration.cfg";
                
                switch ( __phase ) {
                    case 1:
                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.removeFileIfExists( _timeout, user_properties_configuration_path ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.removeFileIfExists( _timeout, default_properties_configuration_path ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.restart( _timeout, "synchronizer", false ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.restart( _timeout, "arbiter", false ) );
                        break;
                    case 2:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PAGE_EDIT.TEST.helpLabelPropertyAndPropertyLabel( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
                        break;
                    case 3:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PAGE_EDIT.TEST.helpLabelPropertyAndPropertyLabel( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
                        break;
                    case 4:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PAGE_EDIT.TEST.helpLabelPropertyAndPropertyLabel( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
                        break;
                    case 5:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PAGE_EDIT.TEST.helpLabelPropertyAndPropertyLabel( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
                        break;
                    case 6:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PAGE_EDIT.TEST.helpLabelPropertyAndPropertyLabel( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
                        break;
                    case 7:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PAGE_EDIT.TEST.helpLabelPropertyAndPropertyLabel( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
                        break;
                    case 8:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PAGE_EDIT.TEST.helpLabelPropertyAndPropertyLabel( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
                        break;
                    case 9:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PAGE_EDIT.TEST.helpLabelPropertyAndPropertyLabel( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
                        break;
                    case 10:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PAGE_EDIT.TEST.helpLabelPropertyAndPropertyLabel( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
                        break;
                    case 11:
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.goToMode( _timeout, MANAGER.CONST.STATE.WORK_FLOW.STAGING ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, PROPERTY.CONST.NAME.NOTE_URL, "http://00233_test_auto_host_diff" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.saveWithButtonSave( _timeout ) );
                        __do_next = false;
                        break;
                    case 12:
                        break;
                    case 13:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.labelPropertyDiffPopup( _timeout, "00000000000000000000000000000233", PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
                        break;
                    case 14:
                        ____( SHINKEN.TOOLS.TEST_AUTO_APPLY.TEST.labelProperty( _timeout, "00000000000000000000000000000233", PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
                        break;
                    case 15:
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT_EDITION.ACTION.navigateInTab( _timeout, WINDOW.CONST.ELEMENT.CHANGES ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PAGE_EDIT.TEST.labelPropertyDiff( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
                        break;
                    case 16:
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.goToMode( _timeout, MANAGER.CONST.STATE.WORK_FLOW.WORKING_AREA ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.saveWithButtonDifference( _timeout ) );
                        __do_next = false;
                        break;
                    case 17:
                        // TODO A refaire
                        var _navigator = window.open( SHINKEN.HIGHWAY.getPath(), "test", "width=" + window.innerWidth / 1.2 + ",height=" + window.innerHeight / 1.2 );
                        _timeout += 4000;
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.saveWithButtonSubmitToStagging( _timeout, _navigator ) );
                        setTimeout( function () {
                            _navigator.close();
                        }, _timeout + 3000 );
                        
                        break;
                    case 18:
                        break;
                    case 19:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.labelPropertyProposedPopup( _timeout, "00000000000000000000000000000233", PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
                        break;
                    case 20:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PAGE_EDIT.TEST.labelPropertyPropose( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
                        break;
                    case 21:
                        // TODO A refaire
                        var _navigator = window.open( SHINKEN.HIGHWAY.getPath(), "test", "width=" + window.innerWidth / 1.2 + ",height=" + window.innerHeight / 1.2 );
                        _timeout += 3000;
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.saveWithButtonAcceptPropose( _timeout, _navigator ) );
                        setTimeout( function () {
                            _navigator.close();
                        }, _timeout + 4000 );
                        
                        break;
                }
                break;
            case "00235":
                var _user_properties_configuration_path    = "/etc/shinken-user/configuration/elements_default_properties/default_properties_configuration.cfg";
                var _default_properties_configuration_path = "/etc/shinken/_default/elements_default_properties/default_properties_configuration.cfg";
                
                switch ( __phase ) {
                    case 1:
                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.removeFileIfExists( _timeout, _user_properties_configuration_path ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.removeFileIfExists( _timeout, _default_properties_configuration_path ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.restart( _timeout, "synchronizer", false ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.restart( _timeout, "arbiter", false ) );
                        _timeout += 10000; // Wait the restart of Webui module
                        break;
                    case 2:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.addExtraColumn( _timeout, PROPERTY.CONST.NAME.NOTE_URL ) );
                        break;
                    case 3:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.labelColumnHeader( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
                        break;
                    case 4:
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.LIST, "menu_expand_list_all" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LIST_ALL.TEST.columnHeaderLabel( _timeout, "notes_url_for_list", "Url externe" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LIST_ALL.TEST.headerManagerSubMenuListColumnLabel( _timeout, "notes_url_for_list", "Url externe" ) );
                        break;
                    case 5:
                        _timeout += 2000; // Wait for loading page
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_ELEMENT_DETAIL.TEST.labelCommandButton( _timeout, "openNotesUrl", "Ouvrir l'URL externe" ) );
                        break;
                    case 6:
                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_ELEMENT_DETAIL.TEST.labelCommandButton( _timeout, "openNotesUrl", "Ouvrir l'URL externe" ) );
                        //__do_next = false;
                        break;
                }
                break;
            case "00236":
                
                switch ( __phase ) {
                    case 1:
                        ____( SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_00236_favorite_all_right", "test_auto_00236_favorite_all_right" ) );
                        break;
                    case 2:
                        _timeout += 1000;
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.DOM.getAddToFavoriteButton() ) );
                        break;
                    case 3:
                        _timeout += 1000;
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.DOM.getAddToFavoriteButton() ) );
                        break;
                    case 4:
                        ____( SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_00236_no_favorite_create_right", "test_auto_00236_no_favorite_create_right" ) );
                        break;
                    case 5:
                        _timeout += 1000;
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.DOM.getAddToFavoriteButton() ) );
                        break;
                    case 6:
                        _timeout += 1000;
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.DOM.getAddToFavoriteButton() ) );
                        break;
                }
                break;
            default:
                ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LIST_ALL_RUN.do( _timeout ) );
                break;
        }
        return _timeout;
    };
    return self;
})( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN || {} );
